"use strict";

require("core-js/modules/es6.object.define-property");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.unique = unique;
exports.default = exports.checkOverlapRectangles = exports.canDragY = exports.canDragX = exports.getMaxDistance = exports.createCoreData = exports.checkArrayWithPush = exports.noop = void 0;

require("core-js/modules/es6.array.sort");

require("core-js/modules/es6.array.is-array");

require("core-js/modules/es6.array.find-index");

var noop = function noop() {};

exports.noop = noop;

function unique(array) {
  var compare = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : function (a, b) {
    return a === b;
  };
  var result = [];

  var _loop = function _loop(i, len) {
    var current = array[i];

    if (result.findIndex(function (v) {
      return compare(v, current);
    }) === -1) {
      result.push(current);
    }
  };

  for (var i = 0, len = array.length; i < len; i++) {
    _loop(i, len);
  }

  return result;
}

var checkArrayWithPush = function checkArrayWithPush(target, key, value) {
  if (Array.isArray(target[key])) {
    target[key].push(value);
  } else {
    target[key] = [value];
  }
};

exports.checkArrayWithPush = checkArrayWithPush;

var createCoreData = function createCoreData(_ref, _ref2) {
  var node = _ref.node,
      deltaX = _ref.deltaX,
      deltaY = _ref.deltaY;
  var originX = _ref2.originX,
      originY = _ref2.originY,
      x = _ref2.x,
      y = _ref2.y;
  return {
    node: node,
    deltaY: deltaY,
    deltaX: deltaX,
    originX: originX || x,
    originY: originY || y,
    x: x,
    y: y
  };
};

exports.createCoreData = createCoreData;

var getMaxDistance = function getMaxDistance(arr) {
  var num = arr.sort(function (a, b) {
    return a - b;
  });
  return num[num.length - 1] - num[0];
};

exports.getMaxDistance = getMaxDistance;

var canDragX = function canDragX(axis) {
  return axis === 'both' || axis === 'x';
};

exports.canDragX = canDragX;

var canDragY = function canDragY(axis) {
  return axis === 'both' || axis === 'y';
};

exports.canDragY = canDragY;

var checkOverlapRectangles = function checkOverlapRectangles(_ref3, _ref4) {
  var x1 = _ref3.x,
      y1 = _ref3.y,
      w1 = _ref3.w,
      h1 = _ref3.h;
  var x2 = _ref4.x,
      y2 = _ref4.y,
      w2 = _ref4.w,
      h2 = _ref4.h;
  return x1 < x2 + w2 && x1 + w1 > x2 && y1 < y2 + h2 && y1 + h1 > y2;
};

exports.checkOverlapRectangles = checkOverlapRectangles;
var _default = {
  noop: noop,
  unique: unique,
  createCoreData: createCoreData,
  checkArrayWithPush: checkArrayWithPush,
  canDragX: canDragX,
  canDragY: canDragY,
  checkOverlapRectangles: checkOverlapRectangles
};
exports.default = _default;